/**
 * Converts a Blob to a File with a default name like "image.png".
 *
 * If it is already a File object, it is returned unchanged.
 *
 * @param fileOrBlob Blob object.
 * @return File object.
 */
export declare function convertBlobToFile(fileOrBlob: Blob | File): File;
/**
 * Renames a given file and returns a new file.
 *
 * Copies over the last modified time.
 *
 * @param file File object.
 * @param name File name.
 * @return Renamed file object.
 */
export declare function renameFile(file: File, name: string): File;
/**
 * Clones a given file object.
 *
 * @param file File object.
 * @return New file object.
 */
export declare function cloneFile(file: File): File;
/**
 * Returns the file extension from a given file name or URL.
 *
 * @param file File URL.
 * @return File extension or null if it does not have one.
 */
export declare function getFileExtension(file: string): string | null;
/**
 * Returns file basename without extension.
 *
 * For example, turns "my-awesome-file.jpeg" into "my-awesome-file".
 *
 * @param name File name.
 * @return File basename.
 */
export declare function getFileBasename(name: string): string;
/**
 * Returns the file name including extension from a URL.
 *
 * @param url File URL.
 * @return File name.
 */
export declare function getFileNameFromUrl(url: string): string;
//# sourceMappingURL=utils.d.ts.map